<?php
/*
Plugin Name: eat.ly widget for Wordpress
Plugin URI: http://labs.thesedays.com/projects/eatly_for_wordpress/
Description: Shows your latest food items
Version: 1.0
Author: Sam Serrien
Author URI: http://twitter.com/samzzi
*/

add_action("widgets_init", array("Eatly_widget", "register"));

register_activation_hook( __FILE__, array("Eatly_widget", "activate"));
register_deactivation_hook( __FILE__, array("Eatly_widget", "deactivate"));

class Eatly_widget {
	private static $max_items = 20;
	private static $rss_url = "http://eat.ly/{username}.rss";

	function activate(){
		$data = array("title"=>"Eat.ly", "username"=>"", "opt_max_items"=>5, "opt_show_title"=>1, "opt_show_photo"=>0, "opt_show_date"=>0, "opt_show_time"=>0, "opt_link_to_image"=>0);

	    if (!get_option("eatly_widget")) {
			add_option("eatly_widget" , $data);
	    } else {
			update_option("eatly_widget" , $data);
	    }
	}

	function deactivate(){
		delete_option("eatly_widget");
	}

	function control(){
		$data = get_option("eatly_widget");

		if($data["opt_show_title"]) $show_title_checked = " checked"; else $show_title_checked = "";
		if($data["opt_show_photo"]) $show_photo_checked = " checked"; else $show_photo_checked = "";
		if($data["opt_show_date"]) $show_date_checked = " checked"; else $show_date_checked = "";
		if($data["opt_show_time"]) $show_time_checked = " checked"; else $show_time_checked = "";
		if($data["opt_link_to_image"]) $link_to_image_checked = " checked"; else $link_to_image_checked = "";

		echo "<p><label for=\"eatly_widget_title\">Title:</label> <input class=\"widefat\" name=\"eatly_widget_title\" id=\"eatly_widget_title\" type=\"text\" value=\"". $data["title"] ."\" /></p>";
		echo "<p><label for=\"eatly_widget_username\">Username:</label> <input class=\"widefat\" name=\"eatly_widget_username\" id=\"eatly_widget_username\" type=\"text\" value=\"". $data["username"] ."\" /></p>";
		echo "<p><label for=\"eatly_widget_max_items\">Maximum number of items to show:</label> <select id=\"eatly_widget_max_items\" name=\"eatly_widget_max_items\">";

		for($i=1; $i<=self::$max_items; $i++) {
			if($i == $data["opt_max_items"]) $selected = " selected";
			else $selected = "";

			echo "<option value=\"". $i ."\"". $selected .">". $i ."</option>";
		}

		echo "</select></p>";
		echo "<p><input class=\"checkbox\" type=\"checkbox\" id=\"eatly_widget_show_title\" name=\"eatly_widget_show_title\" ". $show_title_checked ."/> <label for=\"widget_eatly_item_title\">Show eat.ly item title</label></p>";
		echo "<p><input class=\"checkbox\" type=\"checkbox\" id=\"eatly_widget_show_photo\" name=\"eatly_widget_show_photo\" ". $show_photo_checked ."/> <label for=\"widget_eatly_item_photo\">Show eat.ly item photo</label></p>";
		echo "<p><input class=\"checkbox\" type=\"checkbox\" id=\"eatly_widget_show_date\" name=\"eatly_widget_show_date\" ". $show_date_checked ."/> <label for=\"widget_eatly_show_date\">Show eat.ly item date</label></p>";
		echo "<p><input class=\"checkbox\" type=\"checkbox\" id=\"eatly_widget_show_time\" name=\"eatly_widget_show_time\" ". $show_time_checked ."/> <label for=\"widget_eatly_show_time\">Show eat.ly item time</label></p>";
		echo "<p><input class=\"checkbox\" type=\"checkbox\" id=\"eatly_widget_link_to_image\" name=\"eatly_widget_link_to_image\" ". $link_to_image_checked ."/> <label for=\"widget_eatly_link_to_image\">Link photo to image</label></p>";

		if(isset($_POST["eatly_widget_title"])){
		    $data["title"] = attribute_escape($_POST["eatly_widget_title"]);
		    $data["username"] = attribute_escape($_POST["eatly_widget_username"]);
			$data["opt_max_items"] = attribute_escape($_POST["eatly_widget_max_items"]);
			$data["opt_show_title"] = attribute_escape($_POST["eatly_widget_show_title"]);
			$data["opt_show_photo"] = attribute_escape($_POST["eatly_widget_show_photo"]);
			$data["opt_show_date"] = attribute_escape($_POST["eatly_widget_show_date"]);
			$data["opt_show_time"] = attribute_escape($_POST["eatly_widget_show_time"]);
			$data["opt_link_to_image"] = attribute_escape($_POST["eatly_widget_link_to_image"]);

		    update_option("eatly_widget", $data);
		}
	}

	function widget($args){
		include_once(ABSPATH . WPINC . "/rss.php");

		$data = get_option("eatly_widget");

		echo $args["before_widget"];
	    echo $args["before_title"] ."<a href=\"http://eat.ly/". $data["username"] ."\" class=\"eatly_title_link\" target=\"_blank\">". $data["title"] ."</a>". $args["after_title"];

		$rss = str_replace("{username}", $data["username"], self::$rss_url);

		$food_all = fetch_rss($rss);

		if(count($food_all->items)<$data["opt_max_items"])
			$t = count($food_all->items);
		else
			$t = $data["opt_max_items"];

		for($i=0; $i<$t; $i++) {
			$food[$i] = $food_all->items[$i];
		}

		echo "<ul class=\"eatly\">";

		if(empty($data["username"])) {
			echo "<li>Username not configured</li>";
		} else {
			if(empty($food)) {
				echo "<li>Nothing logged yet";
			} else {
				foreach($food as $meal) {
					$title = $meal["title"];		
					$link = $meal["link"];
					$pubdate = $meal["pubdate"];
					$date = date("Y-m-d",strtotime($pubdate));
					$time = date("H:i",strtotime($pubdate));

					$photo = str_replace("medium","small",$meal["description"]);
					$photo = str_replace("<br /><br />","",$photo);

					$image = str_replace("\" />","",$meal["description"]);
					$image = str_replace("<br /><br />","",$image);
					$image = str_replace("<img alt=\"Photo\" src=\"","",$image);

					echo "<li class=\"eatly_widget_item\">";
		
					if($data["opt_show_title"]) {
						echo "<a href=\"". $link ."\" class=\"eatly-link\" target=\"_blank\">". $title ."</a>";

						if($data["opt_show_photo"]) echo "<br /><br />";
					}

					if($data["opt_show_photo"]) {
						if($data["opt_link_to_image"]) {
							echo "<a href=\"". $image ."\" class=\"eatly-link\" target=\"_blank\">". $photo ."</a>";
						} else {
							echo "<a href=\"". $link ."\" class=\"eatly-link\" target=\"_blank\">". $photo ."</a>";
						}
					}
					if($data["opt_show_date"] && !$data["opt_show_time"]) echo " (". $date .")";
					if($data["opt_show_time"] && !$data["opt_show_date"]) echo " (". $time .")";
					if($data["opt_show_date"] && $data["opt_show_time"]) echo " (". $date ." ". $time .")";

					echo "</li><br />";
				}
			}
		}

		echo "</ul>". $args["after_widget"]; 
	}

	function register(){
		register_sidebar_widget("Eat.ly", array("Eatly_widget", "widget"));
		register_widget_control("Eat.ly", array("Eatly_widget", "control"));
	}
}

?>